import Cookies from 'js-cookie'
import storage from 'good-storage'

const Cache = {
  TOKEN: 'token',
  MENUTYPE: 'menuType',
  PERMISSION: 'permission',
  OPENEDPAGES: 'openedPages',
  BREADCRUMB: 'breadcrumb',
  setToken: function(token) {
    storage.set(this.TOKEN, token)
    return token
  },
  setPermission: function(val) {
    storage.set(this.PERMISSION, val)
    return val
  },
  getToken: function() {
    return storage.get(this.TOKEN, '')
  },
  setMenuType: function(menuType) {
    storage.set(this.MENUTYPE, menuType)
    return menuType
  },
  getMenuType: function() {
    return storage.get(this.MENUTYPE, '')
  },
  getPermission: function() {
    return storage.get(this.PERMISSION, [])
  },
  clearToken: function() {
    storage.remove(this.TOKEN)
    return ''
  },
  clearPermission: function() {
    storage.remove(this.PERMISSION)
    storage.remove(this.MENUTYPE)
    return []
  },
  setOpenedPages: function(val) {
    storage.set(this.OPENEDPAGES, val)
    return val
  },
  getOpenedPages: function() {
    return storage.get(this.OPENEDPAGES, [])
  },
  clearOpenedPages: function() {
    storage.remove(this.OPENEDPAGES)
    return []
  },
  setBreadcrumb: function(val) {
    storage.set(this.BREADCRUMB, val)
    return val
  },
  getBreadcrumb: function() {
    return storage.get(this.BREADCRUMB, [])
  },
  clearBreadcrumb: function() {
    storage.remove(this.BREADCRUMB)
    return []
  },
  insertOpenedPages: function(data) {
    let pages = Cache.getOpenedPages()

    let flag = pages.some(v => {
      let pathEq = v.path === data.path
      let queryEq = JSON.stringify(v.query) === JSON.stringify(data.query)

      return pathEq && queryEq
    })

    if (!flag) {
      pages.push(data)
    }
    Cache.setOpenedPages(pages)
    return pages
  },
  deleteOpenedPages: function(data) {
    let pages = Cache.getOpenedPages()

    for (let [i, v] of pages.entries()) {
      let pathEq = v.path === data.path
      let queryEq = JSON.stringify(v.query) === JSON.stringify(data.query)

      if (pathEq && queryEq) {
        pages.splice(i, 1)
      }
    }
    Cache.setOpenedPages(pages)
    return pages
  },
  getTagNavList: function(data) {
    let list = []
    this.flatNavList(data, list)
    return list
  },
  flatNavList(obj, list) {
    for (let v of obj) {
      if (v.child && v.child.length) {
        this.flatNavList(v.child, list)
      } else {
        list.push(v)
      }
    }
  }
}

const Auth = {
  // 在Cookie中记录登录状态的key
  loginKey: 'userInfo',

  // 当前是否是登录状态
  getLoginInfo: function() {
    return Cookies.get(this.loginKey)
  },

  // 设置登录状态
  setLoginInfo: function(obj) {
    // TODO: 设置超时登录时间，在该时间范围内没有任何请求操作则自动删除
    var maxAge = new Date(new Date().getTime() + 30 * 60 * 1000)
    Cookies.set(this.loginKey, obj, {
      expires: maxAge
    })
    return obj
  },

  // 移除登录状态
  clearLoginInfo: function() {
    Cookies.remove(this.loginKey)
  }
}

export {Auth, Cache}
